@@ -1,6 +1,6 @@
 /// Modelled after std::option::Option
 /// See: https://doc.rust-lang.org/std/option/enum.Option.html#variant.None
-#[derive(PartialEq,Debug)]
+#[derive(Clone,Copy,PartialEq,Debug)]
 pub enum Quizas<T> {
     Nada,
     Algo(T),
@@ -26,6 +26,12 @@ impl<T> Into<Option<T>> for Quizas<T> {
     }
 }
 
+impl<T> Default for Quizas<T> {
+    fn default() -> Self {
+        Nada
+    }
+}
+
 impl<T> Quizas<T> {
     pub fn unwrap(self) -> T {
         match self {
@@ -147,4 +153,17 @@ mod tests {
     fn nada_into_works(){
         let _ft: Option<i32> = Nada::<i32>.into();
     }
+
+    #[test]
+    fn default_works(){
+        assert_eq!(Nada, Quizas::<i32>::default());
+    }
+
+    /*
+    #[test]
+    fn enum_value(){
+        let i = Nada as i32;
+        assert_eq!(i, 0);
+    }
+    */
 }
